# Changelog

## [0.1.2] - 2026-02-17
- Iterative workflow upgraded to C++ backend (significant speedup)
- Comprehensive refinements across the codebase

## [0.1.1] - 2025-11

## [0.1.0] - 2025-11
- Initial public release
